@@ -287,6 +287,9 @@ class Selenium(Scraper):
         else:
             self.driver.switch_to.frame(element)
 
+    def on_screenshot(self, file: str) -> None:
+        self.driver.get_screenshot_as_file(file)
+
     def on_freeze(self) -> None:
         self.driver.execute_cdp_cmd('Emulation.setScriptExecutionDisabled', { 'value': True })
 
